@@ -6,6 +6,7 @@ import typer
 
 from enum import Enum
 from pathlib import Path
+from importlib.metadata import version
 
 import faster_whisper
 
@@ -74,6 +75,16 @@ def main(
         "--llm-api-key",
         help="API key for the LLM server; No need to set if using local Ollama server",
     ),
+    to_timestamp_paragraphs: bool = typer.Option(
+        False,
+        "--timestamp-paragraphs",
+        help="Prepend timestamp to paragraphs",
+    ),
+    add_table_of_contents: bool = typer.Option(
+        False,
+        "--add-table-of-contents",
+        help="Add table of contents at the beginning of the document",
+    ),
     skip_cache: typing.Annotated[
         bool,
         typer.Option("--skip-cache", help="If should skip reading from cache"),
@@ -84,7 +95,26 @@ def main(
             "--segment-unchaptered", help="Segment unchaptered video by topic"
         ),
     ] = False,
+    ignore_source_chapters: typing.Annotated[
+        bool,
+        typer.Option(
+            "--ignore-source-chapters",
+            "--ignore-chapters",
+            help="Ignore original chapters from the source",
+        ),
+    ] = False,
+    show_version: typing.Annotated[
+        bool,
+        typer.Option(
+            "--version",
+            help="Show the current version of yt2doc",
+        ),
+    ] = False,
 ) -> None:
+    if show_version:
+        typer.echo(version("yt2doc"))
+        return
+
     io_writer = IOWriter()
 
     whisper_adapter: IWhisperAdapter
@@ -136,6 +166,9 @@ def main(
             meta=meta,
             sat_model=sat_model,
             segment_unchaptered=segment_unchaptered,
+            ignore_source_chapters=ignore_source_chapters,
+            to_timestamp_paragraphs=to_timestamp_paragraphs,
+            add_table_of_contents=add_table_of_contents,
             llm_model=llm_model,
             llm_server=llm_server,
             llm_api_key=llm_api_key,
